# delimit ;
clear all;
set mem 200m;
set more off;

version 11;

***Directory Globals:
	global data         "/Users/taniabarham/Documents/MyDocuments/Projects/bangadesh/Cognitive/Data/";
	global regression   "/Users/taniabarham/Documents/MyDocuments/Projects/bangadesh/Cognitive/Code/Publication/";

capture log close;
log using  "${regression}CogReg_June2011_Spillover_Table5.log", replace;

use "${data}cognitiveFinalPublication.dta", clear;
   
do "${regression}BeforeReg_June2011.do";

***Keep cognitive sample only;
	drop if MMSE_total==.;
 	drop if drop_cogsamp==1;
 	
***Make control area boardering treatment area interactions;

    gen     control74     	=1 if treat_dss==0;
    replace control74     	=0 if treat_dss==1;

    gen control74_gr1    	= control74*group1;
    gen control74_gr2   	= control74*group2;
    gen control74_gr3  		= control74*group3;
    gen control74_gr4    	= control74*group4;

    gen bordergis_cont74  	= trtmtbrdr*control74;

    gen bordergis_gr1    	= trtmtbrdr*control74_gr1;
    gen bordergis_gr2   	= trtmtbrdr*control74_gr2;
    gen bordergis_gr3   	= trtmtbrdr*control74_gr3;
    gen bordergis_gr4    	= trtmtbrdr*control74_gr4;
  

**Make distance by quartiles/medians;

    sum trtmtdistc if  trtmtbrdr==1, detail;
        gen dis25=(trtmtdistc<=r(p25)) if trtmtbrdr~=.;
        
foreach var of varlist dis25 {;
    gen bordergis_`var'         = `var'*control74*trtmtbrdr;
    gen bordergis_gr1_`var'    	= `var'*control74_gr1*trtmtbrdr;
    gen bordergis_gr2_`var'   	= `var'*control74_gr2*trtmtbrdr;
    gen bordergis_gr3_`var'   	= `var'*control74_gr3*trtmtbrdr;
    gen bordergis_gr4_`var'    	= `var'*control74_gr4*trtmtbrdr;
};

*** Make globals Spillover interactions;

   global borderDD25_gis   control74 control74_gr4 control74_gr3 control74_gr2 
                           bordergis_cont74  bordergis_gr4 bordergis_gr3 bordergis_gr2 i.group;


   global borderDD25_gis_dis25   control74 control74_gr4 control74_gr3 control74_gr2 
                          bordergis_dis25   bordergis_gr4_dis25 bordergis_gr3_dis25 bordergis_gr2_dis25 i.group;
                                                                       
* **********************************
* Program to run Linear Regressions
* **********************************;

***Robust Regressions;
capture program drop reglin_SO;
program define reglin_SO;

   syntax varlist [if] [pweight];
    tempvar touse;
    mark `touse' `if';

           
           reg `varlist' $borderDD25_gis   $baseline_ch_dss_74_cl  ${dependInd60}  i.yob_mhss1
                       [`weight' `exp'] if `touse' , cluster(vill) ;
                outreg2  using "${regression}CogReg_June2011_SpillOver_Table5",  dec(2) sym(**,*, +) adjr2  append;

           reg `varlist' $borderDD25_gis_dis25   $baseline_ch_dss_74_cl  ${dependInd60}  i.yob_mhss1
                       [`weight' `exp'] if `touse' , cluster(vill) ;
                outreg2 using "${regression}CogReg_June2011_SpillOver_Table5",  dec(2) sym(**,*, +) adjr2  append;
               
 end;

* ==================
*    RUN PROGRAMS
* ==================;


 local zMMSEtot   ZMMSE_total ;

*Open outreg file;
    xi: reg ZMMSE_total $borderDD25_gis ;
      outreg2  using "${regression}CogReg_June2011_SpillOver_Table5", nolabel bdec(1) sym(**,*,+)  replace;

* =====================
*   Run general model
* =====================;
**Spill-Over Effects;

foreach var of local zMMSEtot {;
     reglin_SO `var'; *Unweighted;
     reglin_SO `var' [pweight=new_wt_ind4top] if status==1 & outlier==0; *Weighted;
   
 };

log close;
