
# delimit ;
clear all;
set matsize 5000;
set mem 200m;
set more off;

version 11;

*========================================
* Purpose: This file produced Tables 4, 6 and 7
* NOTE: THE REGRESSION INCLUDING THE GLOBAL FOR BASELINE STATISTICS CANNOT
* 		BE RUN BECAUSE THE BASELINE DATA IS NOT PUBLICALLY AVAILABLE
* 		THE GLOBAL TO INCLUDE THESE DATA HAS BEEN LEFT IN BUT I HAVE CODED IT TO
*       BE AN EMPTY GLOBAL BELOW SO THE CODE RUN - NOT RESULTS WILL NOT BE EXACTLY REPLICATED
*  
*=============================================;

***Directory Globals:
	global data         "/Users/taniabarham/Documents/MyDocuments/Projects/bangadesh/Cognitive/Data/";
	global regression   "/Users/taniabarham/Documents/MyDocuments/Projects/bangadesh/Cognitive/Code/Publication/";

capture log close;
log using  "${regression}CogReg_Jan_2011_Tables4_6_7.log", replace;

use "${data}cognitiveFinalPublication.dta", clear;
 		
     do "${regression}BeforeReg_June2011.do";

**drop observations not relevant to cognitive sample;
	 drop if MMSE_total==.;
 	 drop if drop_cogsamp==1;
	
***Globals for treatment effects for phasing-in of measles;  
   global treatDD25_M1  treat_dss  treat74new_gr6 treat74new_gr5AC treat74new_gr5BD treat74new_gr3 treat74new_gr2  group2 group3 group5 group6 ;
   global treatDD25_M2   area74newAC treat74new_gr6AC  treat74new_gr5AC  treat74new_gr3AC treat74new_gr2AC group2 group3 group5 group6;

***RECODE GLOBAL FOR BASELINE CHARACTERISTICS TO EMPTY SO CAN RUN CODE - WILL NOT REPLICATE RESULTS;
   global baseline_ch_dss_74_cl ;
/*NOTE: this code won't run because baseline data not in dataset
***Tube-well water interactions;
   gen treat74_tw            =treat_dss*hhc_drinktw74_cen74_cl;
   gen treat74_gr2_tw        =treat74new_gr2*hhc_drinktw74_cen74_cl;
   gen treat74_gr3_tw        =treat74new_gr3*hhc_drinktw74_cen74_cl;  
   gen treat74_gr4_tw        =treat74new_gr4*hhc_drinktw74_cen74_cl;
   
   gen group1_tw       		=group1*hhc_drinktw74_cen74_cl;
   gen group2_tw       		=group2*hhc_drinktw74_cen74_cl;
   gen group3_tw      		=group3*hhc_drinktw74_cen74_cl;
   gen group4_tw       		=group4*hhc_drinktw74_cen74_cl;
*/

* **********************************
* Programs to run Linear Regressions
* **********************************;

***Double Difference Results for Table 4 of Paper;
	capture program drop reglin_DD;
	program define reglin_DD;

     syntax varlist [if] [pweight];
    tempvar touse;
    mark `touse' `if';

		 *Individual characteristics;
       	 reg  `varlist' $treatDD25new  $dependInd60 i.yob_mhss1
                    [`weight' `exp'] if `touse', cluster(vill)  ;
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;
         
                     
		 *Baseline controls;
       	 reg  `varlist' $treatDD25new $dependInd60  $baseline_ch_dss_74_cl i.yob_mhss1
                    [`weight' `exp'] if `touse' , cluster(vill)  ;
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;
		 
		 *village fixed effects;
 		 areg  `varlist' $treatDD25new $dependInd60 $baseline_ch_dss_74_cl  i.yob_mhss1 
                    [`weight' `exp'] if `touse' , cluster(vill) absorb(treat_vill_dss);
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;

		 *Random Child Sample;
         reg  `varlist' $treatDD25new $dependInd60 $baseline_ch_dss_74_cl i.yob_mhss1
                    [`weight' `exp'] if `touse' & rndmkid==1, cluster(vill)  ;
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;

/* NOTE: will not run because data not available in dataset;
		 *Interaction effects with tubewell water;                               
         reg  `varlist' $treatDD25new  treat74_gr4_tw group4_tw   $baseline_ch_dss_74_cl ${dependInd60} i.yob_mhss1 
                    [`weight' `exp'] if `touse', cluster(vill);
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;
*/

		 *Mother ever eligible for FP;               
         reg  `varlist' $treatDD25new  mom_eligible   $baseline_ch_dss_74_cl ${dependInd60} i.yob_mhss1
                    [`weight' `exp'] if `touse', cluster(vill);
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;

		 *Education fixed-effects - use education from roster so don't lose observations as not an outcome variable - similar results if use it from books but lose obs;
         reg  `varlist' $treatDD25new  i.ed_yrs  $baseline_ch_dss_74_cl ${dependInd60} i.yob_mhss1
                    [`weight' `exp'] if `touse', cluster(vill);
                outreg2  using "${regression}CogReg_Jan_2011_Table4", dec(2)  sym(**,*,+) adjr2  append;

end; * ends prog regslin_DD;

***Robust Regressions: Use for Table 7;
	capture program drop reglin_RR;
	program define reglin_RR;

   	syntax varlist [if] [pweight];
    tempvar touse;
    mark `touse' `if';
 
           reg  `varlist' $treatDD25new    $baseline_ch_dss_74_cl ${dependInd60} i.yob_mhss
                    [`weight' `exp'] if `touse', cluster(vill);
            outreg2    using "${regression}CogReg_Jan_2011_Table7", dec(2)  sym(**,*,+) adjr2  append;                      
end;

***Disaggregated by treatment area: Used for Table 6;
capture program drop reglin_measles;
program define reglin_measles;

     syntax varlist [if] [pweight];
    tempvar touse;
    mark `touse' `if'; 
  
 
          reg  `varlist' $treatDD25_M1    $baseline_ch_dss_74_cl ${dependInd60}   i.yob_mhss 
                    [`weight' `exp'] if `touse' , cluster(vill);
                outreg2  using "${regression}CogReg_Jan_2011_Table6", dec(2)  sym(**,*,+) adjr2  append;

     	  reg `varlist'  $treatDD25_M2   $baseline_ch_dss_74_cl ${dependInd60}  i.yob_mhss 
    	  		[`weight' `exp']  if `touse' & (treat_dss==1), cluster(vill);
               outreg2  using "${regression}CogReg_Jan_2011_Table6",  dec(2)  sym(**,*,+) adjr2 append; 

 
end; * ends prog regslin_measles;

* ==================
*    RUN PROGRAMS
* ==================;
 local zMMSEtot    ZMMSE_total; 
 local zMMSEpart2  Zorientation_total Zcalc_total Zrecall_total Zregistration_total  Zlanguage_total;
	

*Open outreg file;
    xi: reg ZMMSE_total $treatDD25new , cluster(vill);
          outreg2  using "${regression}CogReg_Jan_2011_Table4",  		bdec(1) sym(**,*,+) replace;
          outreg2  using "${regression}CogReg_Jan_2011_Table6",  	bdec(1) sym(**,*,+) replace;
          outreg2  using "${regression}CogReg_Jan_2011_Table7",  	bdec(1) sym(**,*,+) replace;

* =====================
*   Run models
* =====================;

***Table 4: Main DD results;

foreach var of local zMMSEtot {;     
     reglin_DD  `var' ; *Unweighted results;
	};

foreach var of local zMMSEtot {;     
      reglin_DD  `var' [pweight=new_wt_ind4top] if outlier==0; *Weight results web appendix;
	};		      

***Table 6: Results dissaggregated by treatment area; 
foreach var of local zMMSEtot {;
     reglin_measles `var' ;  *Unweighted results;  
     reglin_measles `var' [pweight=new_wt_ind4top] if  outlier==0 ;  *Weight results in web appendix;         
  
    };

***Table 7: Results by subcomponent of MMSE;


foreach var of local zMMSEpart2 {;
     reglin_RR `var';
};     

foreach var of local zMMSEpart2 {;
     reglin_RR `var' [pweight=new_wt_ind4top] if outlier==0;
 };

log close;
